# API Reference

The functions listed below are automatically generated from the docstrings within the `pysweph` module source code.

```{eval-rst}

.. automodule:: swisseph
   :members:
   :undoc-members:
   :show-inheritance:
